<?php

add_action('ninja_forms_after_submission', 'my_ninja_forms_after_submission');

function my_ninja_forms_after_submission($form_data)
{
    $comma_sep_products = '';
    $enable = get_option('ninja_digi_plugin_enable_' . $form_data['form_id']);
    if ($enable == 'Yes') {
        $email_field = get_option('ninja_register_email_field_key_' . $form_data['form_id']);
        $first_name_field = get_option('ninja_register_first_name_field_key_' . $form_data['form_id']);
        $last_name_field = get_option('ninja_register_last_name_field_key_' . $form_data['form_id']);
        $products = get_option('digi_product_ids_' . $form_data['form_id']);
        $comma_sep_products = implode(",", $products);
        if ($comma_sep_products != '' and isset($form_data['fields_by_key'][$email_field]['value'])) {
            digimember_createOrder($comma_sep_products, $form_data['fields_by_key'][$email_field]['value'],$form_data['fields_by_key'][$first_name_field]['value'], $form_data['fields_by_key'][$last_name_field]['value'] );
        }
    }
}

/**
 * @param mixed $transient
 * @return mixed
 */
function ninja_digimember_update($transient)
{
    if (empty($transient) || !is_object($transient)) {
        return $transient;
    }

    $filePath = WP_CONTENT_DIR . '/plugins/ninja-digimember/plugin.php';
    if (!file_exists($filePath)) {
        return $transient;
    }
    $pluginData = get_plugin_data($filePath);
    if (!array_key_exists('Version', $pluginData)) {
        return $transient;
    }
    $pluginVersion = $pluginData['Version'];

    $update = ninja_digimember_fetchUpdateFromServer();
    if (is_array($update) && array_key_exists('latestVersion', $update) && array_key_exists('url', $update) && array_key_exists('slug', $update) && $update['latestVersion'] != null) {
        if (version_compare($update['latestVersion'], $pluginVersion, '>')) {
            $updateInfo = new stdClass();

            $pluginFile = $update['slug'] . '/plugin.php';
            $updateInfo->new_version = $update['latestVersion'];
            $updateInfo->slug = $update['slug'];
            $updateInfo->plugin = $pluginFile;
            $updateInfo->url = 'https://digimember.de';
            $updateInfo->package = $update['url'];
//            $updateInfo->icons = ['default' => $flytools->icon . '?v=' . $updateInfo->new_version];
            $updateInfo->tested = get_bloginfo('version');

            $transient->response[$pluginFile] = (object)(array)$updateInfo;
        }
    }

    return $transient;
}

add_filter('pre_set_site_transient_update_plugins', 'ninja_digimember_update');

/**
 * @return null|array
 */
function ninja_digimember_fetchUpdateFromServer()
{
    $query = '
        {
            pluginVersions {
                slug
                latestVersion
                url
            }
        }
    ';

    $url = 'https://api.flytools.de';

    $post = wp_remote_post($url, ['body' => ['query' => $query]]);
    $response = json_decode(wp_remote_retrieve_body($post), true);
    if (is_array($response)) {
        if (array_key_exists('data', $response) && array_key_exists('pluginVersions', $response['data'])) {
            foreach ($response['data']['pluginVersions'] as $pluginVersion) {
                if (array_key_exists('slug', $pluginVersion) && array_key_exists('latestVersion', $pluginVersion) && array_key_exists('url', $pluginVersion) && $pluginVersion['slug'] == 'ninja-digimember') {
                    return $pluginVersion;
                }
            }
        }
    }

    return null;
}