<?php

final class ninja_digi_settings {

    public function __construct() {
        add_action( 'admin_init', array( $this, 'ninja_digi_settings_tab_f' ), 12 );
        add_filter( 'ninja_forms_settings_tabs', array( $this, 'filter_ninja_forms_settings_tabs' ), 10, 1 );
        add_action( 'admin_init', array( $this, 'save' ) );
        add_action( 'admin_enqueue_scripts', array( $this, 'load_scripts' ) );
    }

    public function filter_ninja_forms_settings_tabs( $array ) {
        $array['ninja_digi'] = __( 'DigiMember Integration', 'ninja-forms' );
        return $array;
    }

    public function ninja_digi_settings_tab_f(){
        add_meta_box( 'nf_settings_ninja_digi',	__( 'DigiMember Integration', 'ninja-forms' ),	 array( $this, 'settings' ) ,'nf_settings_ninja_digi');
    }

    public function load_scripts(){
        wp_enqueue_script( 'ninja-digi', plugin_dir_url( __FILE__ ) . '/ninja-digi.js' );
    }

    public function save(){
        if(isset($_POST['digi_option']) and $_POST['digi_option'] == "ninja_digi_save_settings"){

            if ( ! isset( $_POST['ninja_digi_save_action_field'] ) || ! wp_verify_nonce( $_POST['ninja_digi_save_action_field'], 'ninja_digi_save_action' ) ) {
                wp_die( _ninjaDigi('Sorry, your nonce did not verify.'));
            }

            $digi_form_id = sanitize_text_field($_REQUEST['digi_form_id']);

            if(isset($_POST['ninja_digi_plugin_enable_'.$digi_form_id])){
                update_option( 'ninja_digi_plugin_enable_'.$digi_form_id, sanitize_text_field($_POST['ninja_digi_plugin_enable_'.$digi_form_id]) );
            } else {
                delete_option( 'ninja_digi_plugin_enable_'.$digi_form_id );
            }

            if(isset($_POST['ninja_register_email_field_key_'.$digi_form_id])){
                update_option( 'ninja_register_email_field_key_'.$digi_form_id, sanitize_text_field($_POST['ninja_register_email_field_key_'.$digi_form_id]) );
            } else {
                delete_option( 'ninja_register_email_field_key_'.$digi_form_id );
            }

            if(isset($_POST['ninja_register_first_name_field_key_'.$digi_form_id])){
                update_option( 'ninja_register_first_name_field_key_'.$digi_form_id, sanitize_text_field($_POST['ninja_register_first_name_field_key_'.$digi_form_id]) );
            } else {
                delete_option( 'ninja_register_first_name_field_key_'.$digi_form_id );
            }

            if(isset($_POST['ninja_register_last_name_field_key_'.$digi_form_id])){
                update_option( 'ninja_register_last_name_field_key_'.$digi_form_id, sanitize_text_field($_POST['ninja_register_last_name_field_key_'.$digi_form_id]) );
            } else {
                delete_option( 'ninja_register_last_name_field_key_'.$digi_form_id );
            }


            if(isset($_POST['digi_product_ids_'.$digi_form_id])){
                update_option( 'digi_product_ids_'.$digi_form_id, array_map( 'sanitize_text_field', $_POST['digi_product_ids_'.$digi_form_id] ) );
            } else {
                delete_option( 'digi_product_ids_'.$digi_form_id );
            }
        }
    }

    public function settings(){
        $forms =  ninja_forms_get_all_forms();
        $digi_form_id = (int)sanitize_text_field($_REQUEST['digi_form_id']);
        ?>
        <table class="form-table">
            <form action="" method="post">
                <input type="hidden" name="digi_option" value="ninja_digi_save_settings">
                <?php wp_nonce_field( 'ninja_digi_save_action', 'ninja_digi_save_action_field' );?>
                <tbody>
                <tr>
                    <th scope="row"> <label for="digi_form_id">
                            <?php _ninjaDigi('Select Ninja Form:');?>
                        </label>
                    </th>
                    <td><select name="digi_form_id" onChange="digiDoReload(this.value);">
                            <option value="">-</option>
                            <?php
                            if( is_array($forms) ){
                                foreach( $forms as $key => $value ){
                                    if( $digi_form_id == $value['id'] ){
                                        echo '<option value="'.$value['id'].'" selected>'.$value['name'].'</option>';
                                    } else {
                                        echo '<option value="'.$value['id'].'">'.$value['name'].'</option>';
                                    }
                                }
                            }
                            ?>
                        </select>
                        <p>
                            <?php echo _ninjaDigi('Please select a Ninja Form');?>
                        </p></td>
                </tr>
                </tbody>
                <?php if( $digi_form_id != '' ){
                    $enable = get_option('ninja_digi_plugin_enable_' . $digi_form_id);
                    $email_field = get_option('ninja_register_email_field_key_' . $digi_form_id);
                    $first_name_field = get_option('ninja_register_first_name_field_key_' . $digi_form_id);
                    $last_name_field = get_option('ninja_register_last_name_field_key_' . $digi_form_id);
                    $products = get_option('digi_product_ids_' . $digi_form_id);
                    ?>
                    <tbody>
                    <tr>
                        <th scope="row"> <label for="ninja_digi_plugin_enable">
                                <?php echo _ninjaDigi('Activate');?>
                            </label>
                        </th>
                        <td><input type="checkbox" name="ninja_digi_plugin_enable_<?php echo $digi_form_id;?>" <?php echo $enable == 'Yes'?'checked="checked"':'';?> value="Yes" >
                            <p>
                                <?php echo _ninjaDigi('Activate and allow access to DigiMember (mandatory setting)');?>
                            </p></td>
                    </tr>
                    </tbody>
                    <tbody>
                    <tr>
                        <th scope="row"> <label for="ninja_register_email_field">
                                <?php echo _ninjaDigi('Mapping');?>
                            </label>
                        </th>
                        <td>
                            <select name="ninja_register_email_field_key_<?php echo $digi_form_id;?>">
                                <option value="">-</option>
                                <?php
                                $form_fields = ninja_forms_get_fields_by_form_id($digi_form_id);
                                if( is_array($form_fields) ){
                                    foreach( $form_fields as $key1 => $value1 ){
                                        if( $email_field == $value1['data']['key'] ){
                                            echo '<option value="'.$value1['data']['key'].'" selected>'.$value1['data']['label'].'</option>';
                                        } else {
                                            echo '<option value="'.$value1['data']['key'].'">'.$value1['data']['label'].'</option>';
                                        }
                                    }
                                }
                                ?>
                            </select>
                            <p><?php echo _ninjaDigi('Select e-mail field from'); ?>
                                <a href="admin.php?page=ninja-forms&form_id=<?php echo $digi_form_id; ?>">
                                    <?php echo _ninjaDigi('Ninja Form.'); ?>
                                </a>

                                <br>
                                <br>

                                <select name="ninja_register_first_name_field_key_<?php echo $digi_form_id;?>">
                                    <option value="">-</option>
                                    <?php
                                    $form_fields = ninja_forms_get_fields_by_form_id($digi_form_id);
                                    if( is_array($form_fields) ){
                                        foreach( $form_fields as $key1 => $value1 ){
                                            if( $first_name_field == $value1['data']['key'] ){
                                                echo '<option value="'.$value1['data']['key'].'" selected>'.$value1['data']['label'].'</option>';
                                            } else {
                                                echo '<option value="'.$value1['data']['key'].'">'.$value1['data']['label'].'</option>';
                                            }
                                        }
                                    }
                                    ?>
                                </select>

                            <p>
                                <?php echo _ninjaDigi('Select First Name field from'); ?>
                                <a href="admin.php?page=ninja-forms&form_id=<?php echo $digi_form_id; ?>">
                                    <?php echo 'Ninja Form.'; ?>
                                </a>
                            </p>

                            <br>
                            <br>

                            <select name="ninja_register_last_name_field_key_<?php echo $digi_form_id;?>">
                                <option value="">-</option>
                                <?php
                                $form_fields = ninja_forms_get_fields_by_form_id($digi_form_id);
                                if( is_array($form_fields) ){
                                    foreach( $form_fields as $key1 => $value1 ){
                                        if( $last_name_field == $value1['data']['key'] ){
                                            echo '<option value="'.$value1['data']['key'].'" selected>'.$value1['data']['label'].'</option>';
                                        } else {
                                            echo '<option value="'.$value1['data']['key'].'">'.$value1['data']['label'].'</option>';
                                        }
                                    }
                                }
                                ?>
                            </select>
                            <p>
                                <?php echo _ninjaDigi('Select Last Name field from');?>
                                <a href="admin.php?page=ninja-forms&form_id=<?php echo $digi_form_id;?>">
                                    <?php echo 'Ninja Form.';?>
                                </a>
                            </p
                        </td>
                    </tr>
                    </tbody>
                    <tbody>
                    <tr>
                        <th scope="row"> <label for="digi_product_ids">
                                <?php echo _ninjaDigi('Select matching DigiMember product');?>
                            </label>
                        </th>
                        <td><?php
                            if(function_exists('digimember_listProducts')){
                                $products_list = digimember_listProducts();
                            }
                            if( is_array($products_list) ){
                                foreach( $products_list as $key2 => $value2 ){?>
                                    <input type="checkbox" name="digi_product_ids_<?php echo $digi_form_id;?>[]" value="<?php echo $value2->id;?>" <?php echo (is_array($products) and in_array($value2->id,$products))?'checked':'' ?>>
                                    <?php echo $value2->name;?>
                                <?php }
                            }
                            ?></td>
                    </tr>
                    </tbody>
                <?php } ?>
                <tbody>
                <th scope="row"><input type="submit" name="submit" class="button button-primary" value="<?php _e(_ninjaDigi('Save Settings'),'ninja-forms');?>"></th>
                </tbody>

            </form>
        </table>
        <?php
    }

}